@@ -8,6 +8,7 @@ from longling.ML.toolkit import MovingLoss
 from longling.ML.toolkit import ConsoleProgressMonitor
 from tqdm import tqdm
 from longling.ML import get_epoch_params_filepath
+from longling.ML.const import RESULT_LOG
 
 
 def train(
@@ -18,19 +19,30 @@ def train(
         fit_f, eval_f=None, net_init=None, get_net=None, get_loss=None, get_trainer=None, save_params=None,
         enable_hyper_search=False, reporthook=None, final_reporthook=None, primary_key=None,
         eval_epoch=1, loss_dict2tmt_loss=None, epoch_lr_scheduler=None, batch_lr_scheduler=None, loss_as_dict=False,
-        **cfg_kwargs):
+        verbose=None, dump_cfg=None, **cfg_kwargs):
+    if enable_hyper_search:
+        assert get_net is not None
+        cfg_kwargs, reporthook, final_reporthook, tag = prepare_hyper_search(
+            cfg_kwargs, reporthook, final_reporthook, primary_key=primary_key, with_keys="Epoch", dump=params_save
+        )
+        dump_result = tag
+        verbose = tag if verbose is None else verbose
+        cfg.update(**cfg_kwargs)
+        print("hyper search enabled")
+        print(cfg)
+
+    verbose = True if verbose is None else verbose
+    dump_cfg = dump_cfg if dump_cfg is not None else params_save
+    if dump_cfg:
+        cfg.dump()
+
     net = net if get_net is None else get_net(**cfg.hyper_params)
 
     if net_init is not None:
-        net_init(net, cfg=cfg, **cfg.init_params)
+        net_init(net, cfg=cfg, initializer_kwargs=cfg.init_params)
 
-    if enable_hyper_search:
-        cfg_kwargs, reporthook, final_reporthook, tag = prepare_hyper_search(
-            cfg_kwargs, reporthook, final_reporthook, primary_key=primary_key, with_keys="Epoch"
-        )
-        dump_result = not tag
-
-    ctx = cfg.ctx
+    train_ctx = cfg.ctx if cfg.train_ctx is None else cfg.train_ctx
+    eval_ctx = cfg.ctx if cfg.eval_ctx is None else cfg.eval_ctx
     batch_size = cfg.batch_size
 
     loss_function = get_loss(**cfg.loss_params) if get_loss is not None else loss_function
@@ -60,16 +72,17 @@ def train(
                 "Loss": loss_monitor.losses
             },
             player_type="epoch",
-            total_epoch=cfg.end_epoch - 1
+            total_epoch=cfg.end_epoch - 1,
+            silent=not verbose
         )
     elif progress_monitor is None or progress_monitor == "tqdm":
         def progress_monitor(x, e):
-            return tqdm(x, "Epoch: %s" % e)
+            return tqdm(x, "Epoch: %s" % e, disable=not verbose)
 
     if dump_result:
         from longling import config_logging
         validation_logger = config_logging(
-            filename=path_append(cfg.model_dir, "result.log"),
+            filename=path_append(cfg.model_dir, cfg.get("result_log", RESULT_LOG)),
             logger="%s-validation" % cfg.model_name,
             mode="w",
             log_format="%(message)s",
@@ -101,7 +114,7 @@ def train(
                 trainer=trainer,
                 loss_function=_loss_function,
                 loss_monitor=loss_monitor,
-                ctx=ctx,
+                ctx=train_ctx,
             )
             if batch_lr_scheduler is not None:
                 batch_lr_scheduler.step()
@@ -132,7 +145,7 @@ def train(
             msg, data = evaluation_formatter(
                 iteration=epoch,
                 loss_name_value=dict(loss_monitor.items()),
-                eval_name_value=eval_f(net, test_data, ctx=ctx, **cfg.get("eval_params", {})),
+                eval_name_value=eval_f(net, test_data, ctx=eval_ctx, verbose=verbose, **cfg.get("eval_params", {})),
                 extra_info=None,
                 dump=dump_result,
                 keep={"msg", "data"}
