@@ -1,7 +1,7 @@
 # coding: utf-8
 # create by tongshiwei on 2019-9-1
 
-from .net import get_net, get_bp_loss
 from .fit_eval import fit_f, eval_f
-from .viz import net_viz
 from .init import net_init
+from .net import get_net, get_loss
+from .viz import net_viz
