@@ -10,7 +10,7 @@ def net_initialize(net, model_ctx, *args, **kwargs):
     return set_device(net, model_ctx, *args, **kwargs)
 
 
-def load_net(filename, net, *args, **kwargs):
+def load_net(filename, net, allow_missing=False, *args, **kwargs):
     """
         Load the existing net parameters
 
@@ -21,6 +21,7 @@ def load_net(filename, net, *args, **kwargs):
         net: torch.nn.Module
             The network which has been initialized or
             loaded from the existed model
+        allow_missing: bool
 
         Returns
         -------
@@ -29,5 +30,5 @@ def load_net(filename, net, *args, **kwargs):
     # 根据文件名装载已有的网络参数
     if not os.path.isfile(filename):
         raise FileExistsError("%s does not exist" % filename)
-    net.load_state_dict(torch.load(filename))
+    net.load_state_dict(torch.load(filename), strict=not allow_missing)
     return net
