@@ -1,6 +1,7 @@
 # coding: utf-8
 # 2020/5/10 @ tongshiwei
 
+import warnings
 from longling import loading, print_time
 
 __all__ = ["to_board"]
@@ -9,7 +10,8 @@ from .utils import get_by_key
 
 
 def to_board(src, board_dir, global_step_field, *scalar_fields):
-    from tensorboardX import SummaryWriter
+    with warnings.catch_warnings(record=True):
+        from tensorboardX import SummaryWriter
 
     with SummaryWriter(board_dir) as sw, print_time(
             "to_board: %s -> %s\n step field: %s, fields: %s" % (src, board_dir, global_step_field, scalar_fields)
